function browseSSD(img1, img2, p1, winsize)

if nargin < 3
    givenPoint = 0;
else
    if isempty(p1)
        givenPoint = 0;
    else
        givenPoint = 1;
    end
end

% Size of square window can be specified. Must be odd.
if nargin < 4
    % Size of tracking window
    winsize = 15;
else
    if mod(winsize, 2) == 0
        error('Window size must be odd')
    end
end

% How large is the display?
ss = get(0, 'ScreenSize');
xmin = 50;
ymin = 50;

% Aspect ratio of a standard Matlab window
aspect = 3/4;

% Margins for figure boundaries and menus
xmargin = 10;
ymargin = 90;

% Window size
width1 = round((ss(3) - ss(1) - 2 * xmin - 2 * xmargin) / 2);
height1 = round(width1 * aspect);
height2 = round((ss(4) - ss(2) - 2 * ymin - 2 * ymargin) / 2);
width2 = round(height2 / aspect);
if height2 < height1
    width = width2;
    height = height2;
else
    width = width1;
    height = height1;
end

h = figure(1);
clf
imagesc(img1)
colormap gray
axis image
axis equal
axis off
set(h, 'Position', [xmin ymin + height + ymargin width height])
hold on

if ~givenPoint
    title('Left-click to pick a point. Right-click to exit')
end

h = figure(2);
clf
imagesc(img2)
colormap gray
axis image
axis equal
axis off
set(h, 'Position', [xmin + width + xmargin ymin + height + ymargin width height])
hold on

h = figure(3);
clf
set(h, 'Position', [xmin ymin width height])

h = figure(4);
clf
set(h, 'Position', [xmin + width + xmargin ymin width height])

while 1
    % Let user pick an image point
    figure(1)
    
    if ~givenPoint
		[x, y, button] = ginput(1);
        if button == 3
            break;
        end
    
	    p1 = round([y, x]);
    end
	
    [u, v, s, drange, minVal] = brute_force(img1, img2, p1, winsize);
    
    [ulk, vlk, history] = lucas_kanade(img1, img2, p1, winsize);
    
%     [uqn, vqn, minValQn] = quasi_newton(img1, img2, p1, winsize);
    
    % Retrieve the tracking windows for display
    w1 = window(img1, p1, floor(winsize/2));
	p2 = p1 + [u, v];
	w2 = window(img2, p2, floor(winsize/2));
    
    % Show corresponding points on the two images
    figure(1)
    plot(p1(2), p1(1), '.r')

    figure(2)
    if ~isempty(history)
        hr = history{1}(:, 1);
        hc = history{1}(:, 2);
        plot(hc(2:(end-1)) + p1(2), hr(2:(end-1)) + p1(1), '.b')
        plot(hc + p1(2), hr + p1(1), '-b')
        plot(hc(1) + p1(2), hr(1) + p1(1), '.y')
        if isnan(ulk)
            plot(hc(end) + p1(2), hr(end) + p1(1), 'xg')
            suffix = 'and failed';
        else
            suffix = 'to convergence';
        end
        title(sprintf('Lucas-Kanade took %d steps %s.', length(hr) - 1, suffix))
    end
    plot(p2(2), p2(1), '.r')
    if ~isnan(ulk)
        plot(p1(2) + vlk, p1(1) + ulk, '.g')
    end
	
    % Show the two matching windows
	figure(3)
	clf
	colormap gray
	
	subplot(1, 2, 1)
	imagesc(w1)
	axis image
	axis equal
	axis off
	
	subplot(1, 2, 2)
	imagesc(w2)
	axis image
	axis equal
	axis off
	
    % Show the SSD values as a mesh plot
	figure(4)
	clf
	mesh(drange, drange, s)
    
    % Point out the location of the minimum
    small = 1.01;
	hold on
	plot3(v * [1 1], u * [1 1], [0 minVal], 'r')
	plot3(v * [1 1], u * [1 1], [0 minVal * small], '.r')
    if ~isnan(ulk)
    	title(sprintf('Brute-force dr %d dc %d. Lucas-Kanade dr %.2f dc %.2f', u, v, ulk, vlk))
    else
    	title(sprintf('Brute-force dr %d dc %d. Lucas-Kanade failed.', u, v))
    end
    xlabel('dc')
    ylabel('dr')
    
    % Show the history for Lucas and Kanade
    if ~isempty(history)
        hv = interp2(drange, drange, s, hc, hr) * small;
        plot3(hc, hr, hv, '.b')
    end
    
    axis ij
    rotate3d on
    
    if givenPoint
        break;
    end
end