function [u, v, rho] = quasi_newton(I1, I2, pos, winsize)

% Size of square window can be specified. Must be odd.
if nargin < 4
    % Size of tracking window
    winsize = 15;
else
    if mod(winsize, 2) == 0
        error('Window size must be odd')
    end
end

% Half the SSD window size
hwin = floor(winsize / 2);

d0 = [0; 0];
options = optimset('LargeScale','off');
[d, rho, exitflag, output] = fminunc(@trackResidual, d0, options, pos(:), I1, I2, hwin);
disp(output)

if exitflag <= 0    % No local minimum found
    u = NaN;
    v = NaN;
else
    u = d(1);
    v = d(2);
end